# work around gcc 10 build errors
%global _legacy_common_support 1

%define major 0
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

%define svrmajor 0
%define svrlibname %mklibname svrcore %{svrmajor}
%define svrdevname %mklibname svrcore -d

%global pkgname   dirsrv

%global use_openldap 1
# If perl-Socket-2.000 or newer is available, set 0 to use_Socket6.
%global use_Socket6 0


# Following rh/fedora and disabling nunc-stans
# https://pagure.io/389-ds-base/issue/49893
# https://bugzilla.redhat.com/show_bug.cgi?id=1614501
# To build without nunc-stans, set 0 to use_nunc_stans.
# nunc-stans only builds on x86_64 for now
%ifarch x86_64
%global use_nunc_stans 0
%else
%global use_nunc_stans 0
%endif

%global nunc_stans_ver 0.1.8

# (cg) NB the --with-tmpfiles_d argument below is for user generated config files
# created via DSCreate.pm script - i.e. it should be the /etc/ path, NOT %%_tmpfilesdir

%global with_tmpfiles_d %{_sysconfdir}/tmpfiles.d}

# systemd support
%global groupname %{pkgname}.target

Summary:          389 Directory Server (base)
Name:             389-ds-base
Version:          1.4.0.26
%define subrel 6
Release:          %mkrel 8
License:          GPLv3+
Group:            System/Servers
URL:              http://port389.org/
Source0:          https://releases.pagure.org/%{name}/%{name}-%{version}.tar.bz2
# 389-ds-git.sh should be used to generate the source tarball from git
Source1:          %{name}-git.sh
Source2:          %{name}-devel.README
Source3:          https://git.fedorahosted.org/cgit/nunc-stans.git/snapshot/nunc-stans-%{nunc_stans_ver}.tar.bz2
Patch0:           389-ds-base-1.4.0.26-mga-fix-path-to-nss-headers.patch
Patch1:           389-ds-base-1.4.0.26-CVE-2019-14824.patch
Patch2:           c1926dfc6591b55c4d33f9944de4d7ebe077e964.patch
Patch3:           0034-CVE-2021-4091-BZ-2030367-double-free-of-the-virtual-.patch
Patch4:           389-ds-base-1.4.0.26-CVE-2022-0996.patch
Patch5:           e5e55afa0ea77d529f6546dd6714473d59853704.patch
Patch6:           389-ds-base-1.4.0.26-CVE-2022-1949.patch
Patch7:           0039-Issue-5098-Multiple-issues-around-replication-and-CI.patch
Patch8:           0040-Issue-5418-Sync_repl-may-crash-while-managing-invali.patch

Requires:         %{libname} = %{version}-%{release}
Provides:         ldif2ldbm

BuildRequires:    pkgconfig(nspr)
BuildRequires:    pkgconfig(nss)
BuildRequires:    pkgconfig(krb5)
%if %{use_openldap}
BuildRequires:    openldap-devel
%else
BuildRequires:    mozldap-devel
%endif
BuildRequires:    db-devel

BuildRequires:    pkgconfig(libsasl2)
BuildRequires:    icu
BuildRequires:    libicu-devel
BuildRequires:    pkgconfig(libpcre)
BuildRequires:    gcc-c++
BuildRequires:    doxygen
# The following are needed to build the snmp ldap-agent
BuildRequires:    net-snmp-devel
BuildRequires:    lm_sensors-devel
BuildRequires:    bzip2-devel
BuildRequires:    pkgconfig(zlib)
BuildRequires:    pkgconfig(openssl)
BuildRequires:    tcp_wrappers
# the following is for the pam passthru auth plug-in
BuildRequires:    pam-devel
BuildRequires:    systemd-units
BuildRequires:    pkgconfig(systemd)

# For cockpit
BuildRequires:    rsync

# this is needed for using semanage from our setup scripts
Requires:         policycoreutils-python-utils

Requires(post):   rpm-helper >= %{rpmhelper_required_version}
Requires(preun):  rpm-helper >= %{rpmhelper_required_version}
Requires(pre):    %{_sbindir}/useradd
Requires(pre):    %{_sbindir}/groupadd


# the following are needed for some of our scripts
%if %{use_openldap}
Requires:         openldap-clients
%else
Requires:         mozldap-tools
%endif

# this is needed to setup SSL if you are not using the
# administration server package
Requires:         nss

# these are not found by the auto-dependency method
# they are required to support the mandatory LDAP SASL mechs
Requires:         sasl-plug-gssapi
Requires:         sasl-plug-digestmd5

# this is needed for verify-db.pl
Requires:         db5-utils

# for the init script
Requires(post):   systemd-units
Requires(preun):  systemd-units
Requires(postun): systemd-units

%description
389 Directory Server is an LDAPv3 compliant server.  The base package includes
the LDAP server and command line utilities for server administration.

%package          -n %{libname}
Summary:          Core libraries for 389 Directory Server
Group:            System/Servers
BuildRequires:    pkgconfig(nspr)
BuildRequires:    pkgconfig(nss)
%if %{use_openldap}
BuildRequires:    openldap-devel
%else
BuildRequires:    mozldap-devel
%endif
BuildRequires:    db-devel
BuildRequires:    pkgconfig(libsasl2)
BuildRequires:    libicu-devel
BuildRequires:    pkgconfig(libpcre)
BuildRequires:    pkgconfig(talloc)
BuildRequires:    pkgconfig(libevent)
BuildRequires:    pkgconfig(tevent)
BuildRequires:    libcrack-devel

%description  -n %{libname}
Core libraries for the 389 Directory Server base package.  These libraries
are used by the main package and the -devel package.  This allows the -devel
package to be installed with just the -libs package and without the main package.

%package          -n %{develname}
Summary:          Development libraries for 389 Directory Server
Group:            System/Libraries
Requires:         nspr-devel
Requires:         nss-devel
%if %{use_openldap}
Requires:         openldap-devel
%else
Requires:         mozldap-devel
%endif

%if %{use_nunc_stans}
Requires:         talloc-devel
Requires:         event-devel
Requires:         tevent-devel
%endif

Requires:         %{libname} = %{version}-%{release}
Provides:         %{develname} = %{version}-%{release}


%description      -n %{develname}
Development Libraries and headers for the 389 Directory Server base package.

%package          snmp
Summary:          SNMP Agent for 389 Directory Server
Group:            System/Servers
Requires:         %{name} = %{version}-%{release}


%description      snmp
SNMP Agent for the 389 Directory Server base package.

%package -n cockpit-389-ds
Summary:          Cockpit UI Plugin for configuring and administering the 389 Directory Server
BuildArch:        noarch
#Requires:         cockpit
Requires:         python%{python3_pkgversion}
#Requires:         python%%{python3_pkgversion}-lib389

%description -n cockpit-389-ds
A cockpit UI Plugin for configuring and administering the 389 Directory Server.

%package          -n %{svrlibname}
Summary:          Secure PIN handling using NSS crypto
License:          MPLv2.0
Group:            System/Libraries
Epoch:            1
Conflicts:        %{_lib}389-ds-base0 < %{version}

%description -n %{svrlibname}
svrcore provides applications with several ways to handle secure PIN storage
e.g. in an application that must be restarted, but needs the PIN to unlock the
private key and other crypto material, without user intervention. svrcore uses
the facilities provided by NSS.

%package          -n %{svrdevname}
Summary:          Development files for svrcore
License:          MPLv2.0
Group:            Development/Other
Epoch:            1
Requires:         %{svrlibname} = 1:%{version}-%{release}
Provides:         svrcore-devel = 1:%{version}-%{release}
Conflicts:        %{_lib}389-ds-base-devel < %{version}

%description -n %{svrdevname}
Development libraries and headers for svrcore.

%prep
%setup -q -n %{name}-%{version} -a 3
%if %{use_nunc_stans}
%setup -q -n %{name}-%{version} -T -D -b 3
%endif
%autopatch -p1
cp %{_sourcedir}/%{name}-devel.README README.devel


# Make sure python3 is used in shebangs
# FIX ME!!  This should be fixed in the source code !!!
sed -r -i '1s|^#!\s*/usr/bin.*python.*|#!%{__python3}|' ldap/admin/src/scripts/*.py


%build
%serverbuild
autoreconf -vfi

%if %{use_nunc_stans}
pushd ../nunc-stans-%{nunc_stans_ver}
autoreconf -fi
%configure --with-fhs --libdir=%{_libdir}/%{pkgname}
%make_build
mkdir -p lib
cp .libs/libnunc-stans.so.0.0.0 lib/libnunc-stans.so
mkdir -p include/nunc-stans
cp nunc-stans.h include/nunc-stans/nunc-stans.h
popd
%endif

%if %{use_openldap}
OPENLDAP_FLAG="--with-openldap"
%endif
%{?with_tmpfiles_d: TMPFILES_FLAG="--with-tmpfiles-d=%{with_tmpfiles_d}"}
# hack hack hack https://bugzilla.redhat.com/show_bug.cgi?id=833529
NSSARGS="--with-svrcore-inc=%{_includedir} --with-svrcore-lib=%{_libdir} --with-nss-lib=%{_libdir} --with-nss-inc=%{_includedir}/nss"
%if %{use_nunc_stans}
NUNC_STANS_FLAGS="--enable-nunc-stans --with-nunc-stans=../nunc-stans-%{nunc_stans_ver}"
%endif
%configure --enable-autobind  $OPENLDAP_FLAG $TMPFILES_FLAG \
           --with-systemdsystemunitdir=%{_unitdir} \
           --with-systemdsystemconfdir=%{_sysconfdir}/systemd/system \
           --with-systemdgroupname=%{groupname} $NSSARGS \
           --with-perldir=/usr/bin \
           --with-systemdgroupname=%{groupname} $NSSARGS $NUNC_STANS_FLAGS \
           --with-systemd

# Generate symbolic info for debuggers
export XCFLAGS=$RPM_OPT_FLAGS


%make_build


%install
%if %{use_nunc_stans}
pushd ../nunc-stans-%{nunc_stans_ver}
%make_install
rm -rf %{buildroot}%{_includedir} %{buildroot}%{_datadir} \
    %{buildroot}%{_libdir}/%{pkgname}/pkgconfig
popd
%endif

%make_install

mkdir -p %{buildroot}%{_logdir}/%{pkgname}
mkdir -p %{buildroot}/var/lib/%{pkgname}
mkdir -p %{buildroot}/var/lock/%{pkgname}

# Cockpit directory and file list
find %{buildroot}%{_datadir}/cockpit/389-console -type d | sed -e "s@%{buildroot}@@" | sed -e 's/^/\%dir /' > cockpit.list
find %{buildroot}%{_datadir}/cockpit/389-console -type f | sed -e "s@%{buildroot}@@" >> cockpit.list
echo "%{_datadir}/metainfo/389-console/org.port389.cockpit_console.metainfo.xml" >> cockpit.list

#remove libtool archives and static libs
find %{buildroot} -type f -name "*.la" -delete
find %{buildroot} -type f -name "*.a" -delete

# make sure perl scripts have a proper shebang
sed -i -e 's|#{{PERL-EXEC}}|#!/usr/bin/perl|' %{buildroot}%{_datadir}/%{pkgname}/script-templates/template-*.pl

%pre
# Add the dirsrv user and group accounts
%_pre_useradd %{pkgname} %{_localstatedir}/lib/%{pkgname} /sbin/nologin
%_pre_groupadd %{pkgname} %{_localstatedir}/lib/%{pkgname} /sbin/nologin


%post
output=/dev/null
# We need to do this because the BS doesn't accept the way Fedora (upstream) and others do it.
if [ $1 = 1 ] ; then
    mkdir -p %{_sysconfdir}/systemd/system/%{groupname}.wants
fi
# reload to pick up any changes to systemd files
%{_bindir}/systemctl daemon-reload >/dev/null 2>&1 || :
# reload to pick up any shared lib changes

# find all instances
instances="" # instances that require a restart after upgrade
ninst=0 # number of instances found in total
if [ -n "$DEBUGPOSTTRANS" ] ; then
   output=$DEBUGPOSTTRANS
fi
echo looking for services in %{_sysconfdir}/systemd/system/%{groupname}.wants/* >> $output 2>&1 || :
for service in %{_sysconfdir}/systemd/system/%{groupname}.wants/* ; do
    if [ ! -f "$service" ] ; then continue ; fi # in case nothing matches
    inst=`echo $service | sed -e 's,%{_sysconfdir}/systemd/system/%{groupname}.wants/,,'`
    echo found instance $inst - getting status >> $output 2>&1 || :
    if %{_bindir}/systemctl -q is-active $inst ; then
       echo instance $inst is running >> $output 2>&1 || :
       instances="$instances $inst"
    else
       echo instance $inst is not running >> $output 2>&1 || :
    fi
    ninst=`expr $ninst + 1`
done
if [ $ninst -eq 0 ] ; then
    echo no instances to upgrade >> $output 2>&1 || :
    exit 0 # have no instances to upgrade - just skip the rest
fi
# shutdown all instances
echo shutting down all instances . . . >> $output 2>&1 || :
for inst in $instances ; do
echo stopping instance $inst >> $output 2>&1 || :
/bin/systemctl stop $inst >> $output 2>&1 || :
done
echo remove pid files . . . >> $output 2>&1 || :
%{_bindir}/rm -f /run/%{pkgname}*.pid /run/%{pkgname}*.startpid


# do the upgrade
echo upgrading instances . . . >> $output 2>&1 || :
DEBUGPOSTSETUPOPT=`/usr/bin/echo $DEBUGPOSTSETUP | /usr/bin/sed -e "s/[^d]//g"`
if [ -n "$DEBUGPOSTSETUPOPT" ] ; then
%{_sbindir}/setup-ds.pl -l $output -$DEBUGPOSTSETUPOPT -u -s General.UpdateMode=offline >> $output 2>&1 || :
else
%{_sbindir}/setup-ds.pl -l $output -u -s General.UpdateMode=offline >> $output 2>&1 || :
fi

# restart instances that require it
for inst in $instances ; do
    echo restarting instance $inst >> $output 2>&1 || :
    %{_bindir}/systemctl start $inst >> $output 2>&1 || :
done

%preun
if [ $1 -eq 0 ]; then # Final removal
    # Package removal, not upgrade
    # remove instance specific service files/links
    rm -rf %{_sysconfdir}/systemd/system/%{groupname}.wants/* > /dev/null 2>&1 || :
fi

%postun
if [ $1 = 0 ]; then # Final removal
    rm -rf /run/%{pkgname}
fi
%_postun_userdel %{pkgname}
%_postun_groupdel %{pkgname}

%preun snmp
%_preun_service %{pkgname}-snmp.service %{groupname}

%post snmp
%_post_service  %{pkgname}-snmp

%files
%license LICENSE LICENSE.GPLv3+ LICENSE.openssl
%doc README.devel README.md
%dir %{_sysconfdir}/%{pkgname}
%dir %{_sysconfdir}/%{pkgname}/schema
%config(noreplace)%{_sysconfdir}/%{pkgname}/schema/*.ldif
%dir %{_sysconfdir}/%{pkgname}/config
%config(noreplace)%{_sysconfdir}/%{pkgname}/config/slapd-collations.conf
%config(noreplace)%{_sysconfdir}/%{pkgname}/config/certmap.conf
%config(noreplace)%{_sysconfdir}/%{pkgname}/config/template-initconfig
%config(noreplace)%{_sysconfdir}/sysconfig/%{pkgname}
%config(noreplace)%{_sysconfdir}/sysconfig/%{pkgname}.systemd
%{_datadir}/%{pkgname}
%{_unitdir}/%{pkgname}.target
%{_unitdir}/%{pkgname}@.service
%{_bindir}/*
%{_sbindir}/*
%{_libdir}/%{pkgname}/perl
%{_libdir}/%{pkgname}/python
%{_libdir}/%{pkgname}/plugins/*.so
%{_libexecdir}/ds_selinux_enabled
%{_libexecdir}/ds_selinux_port_query
%{_libexecdir}/ds_systemd_ask_password_acl
%{_prefix}/lib/sysctl.d/*
%{_prefix}/share/gdb/auto-load/usr/sbin/ns-slapd-gdb.py
%dir %{_localstatedir}/lib/%{pkgname}
%dir %{_logdir}/%{pkgname}
%ghost %dir %{_localstatedir}/lock/%{pkgname}
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%exclude %{_sbindir}/ldap-agent*
%exclude %{_mandir}/man1/ldap-agent.1.*

%files -n %{develname}
%license LICENSE LICENSE.GPLv3+ LICENSE.openssl
%doc README.devel README.md
%{_includedir}/%{pkgname}
%{_libdir}/%{pkgname}/libslapd.so
%{_libdir}/%{pkgname}/libsds.so
%{_libdir}/%{pkgname}/libldaputil.so
%{_libdir}/%{pkgname}/libns-dshttpd.so
# It seems these files are always built regardless the global setting.
# %%if %%{use_nunc_stans}
%{_libdir}/%{pkgname}/libnunc-stans.so
# %%endif
%{_libdir}/pkgconfig/*
%exclude %{_libdir}/pkgconfig/svrcore.pc

%files -n %{svrlibname}
%license src/svrcore/LICENSE
%doc src/svrcore/README
%{_libdir}/libsvrcore.so.%{svrmajor}{,.*}

%files -n %{svrdevname}
%license src/svrcore/LICENSE
%doc src/svrcore/README
%{_includedir}/svrcore.h
%{_libdir}/libsvrcore.so
%{_libdir}/pkgconfig/svrcore.pc

%files -n %{libname}
%license LICENSE LICENSE.GPLv3+ LICENSE.openssl
%doc README.md
%{_libdir}/%{pkgname}/libslapd.so.*
%{_libdir}/%{pkgname}/libsds.so.*
%{_libdir}/%{pkgname}/libldaputil.so.*
%{_libdir}/%{pkgname}/libns-dshttpd-%{version}.so
# %%if %%{use_nunc_stans}
%{_libdir}/%{pkgname}/libnunc-stans.so.*
# %%endif

%files snmp
%license LICENSE LICENSE.GPLv3+ LICENSE.openssl
%doc README.md
%config(noreplace)%{_sysconfdir}/%{pkgname}/config/ldap-agent.conf
%{_unitdir}/%{pkgname}-snmp.service
%{_sbindir}/ldap-agent*
%{_mandir}/man1/ldap-agent.1.*

%files -n cockpit-389-ds -f cockpit.list
%doc README.md


%changelog
* Wed Nov 02 2022 ns80 <ns80> 1.4.0.26-8.6.mga8
+ Revision: 1901589
- add patches from CentOS 7 for CVE-2022-2850 (mga#31022)
- backport upstream patch for CVE-2022-1949 (mga#30558)
- add upstream patch for CVE-2022-0918 (mga#30235)
- backport upstream patch for CVE-2022-0996 (mga#30235)
- add patch from CentOS for CVE-2021-4091 (mga#30175)
- add upstream patch for CVE-2021-3652 (mga#29393)

* Mon Nov 30 2020 luigiwalser <luigiwalser> 1.4.0.26-8.mga8
+ Revision: 1650873
- rebuild for icu

* Tue Nov 03 2020 akien <akien> 1.4.0.26-7.mga8
+ Revision: 1641989
- Rebuild for new netsnmp

* Wed Jul 01 2020 wally <wally> 1.4.0.26-6.mga8
+ Revision: 1601010
- rebuild for icu 67.1

* Fri May 22 2020 wally <wally> 1.4.0.26-5.mga8
+ Revision: 1586853
- build with -fcommon
- update policycoreutils requires

* Sat Apr 04 2020 wally <wally> 1.4.0.26-4.mga8
+ Revision: 1564445
- rebuild for new icu 66.1

* Tue Feb 18 2020 umeabot <umeabot> 1.4.0.26-3.mga8
+ Revision: 1540918
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Dec 17 2019 ns80 <ns80> 1.4.0.26-2.mga8
+ Revision: 1468607
- a "normal" package should not depend on devel packages

* Thu Dec 12 2019 ns80 <ns80> 1.4.0.26-1.mga8
+ Revision: 1466036
- Revert to version 1.4.0.26 + patch for CVE-2019-14824 (mga#25824)
- new version 1.4.0.31 for CVE-2018-1054, CVE-2018-10871, CVE-2019-3883, CVE-2019-14824 (mga#25824)

* Sun Nov 24 2019 wally <wally> 1.4.0.18-7.mga8
+ Revision: 1462581
- fix buildrequires

* Sun Nov 24 2019 wally <wally> 1.4.0.18-6.mga8
+ Revision: 1462576
- split out svrcore (mga#25709)
- update %%doc and %%license files

* Sat Oct 05 2019 daviddavid <daviddavid> 1.4.0.18-5.mga8
+ Revision: 1449565
- rebuild for new icu 65.1

* Tue Feb 05 2019 daviddavid <daviddavid> 1.4.0.18-4.mga7
+ Revision: 1363451
- fix dependencies

* Sat Dec 29 2018 luigiwalser <luigiwalser> 1.4.0.18-3.mga7
+ Revision: 1346082
- rebuild for icu

* Sat Dec 29 2018 luigiwalser <luigiwalser> 1.4.0.18-2.mga7
+ Revision: 1346019
- rebuild for net-snmp

* Thu Nov 15 2018 mrambo3501 <mrambo3501> 1.4.0.18-1.mga7
+ Revision: 1330016
- attempt to fix files list
- follow fedora and disable nunc-stans
- add BR for doxygen
- version 1.4.0.18 fixes CVE-2018-14648 (mga#23800)
- added cockpit subpackage and fixed files list with hints from the fedora spec

* Thu Oct 04 2018 mrambo3501 <mrambo3501> 1.3.5.19-8.mga7
+ Revision: 1317550
- rediff upstream patches which fix CVE-2018-10850,10935,14624 (mga#23610)

* Tue Aug 28 2018 daviddavid <daviddavid> 1.3.5.19-7.mga7
+ Revision: 1255193
- rebuild for new icu

* Sat May 12 2018 mrambo3501 <mrambo3501> 1.3.5.19-6.mga7
+ Revision: 1228645
- rediff upsteam patch which fixes CVE-2018-1089 (mga#23005)

* Sat Mar 24 2018 mrambo3501 <mrambo3501> 1.3.5.19-5.mga7
+ Revision: 1211794
- rediff upstream patch which fixes CVE-2017-15135 (mga#22718)

* Wed Mar 07 2018 kekepower <kekepower> 1.3.5.19-4.mga7
+ Revision: 1207027
- Added patch from Redhat to fix CVE-2018-1054 (mga#22710)

* Fri Feb 02 2018 mrambo3501 <mrambo3501> 1.3.5.19-3.mga7
+ Revision: 1198634
- add rediffed fedora patch which fixes CVE-2017-15134 mga#22466

* Fri Dec 29 2017 wally <wally> 1.3.5.19-2.mga7
+ Revision: 1186959
- rebuild for new icu

* Fri Sep 08 2017 mrambo3501 <mrambo3501> 1.3.5.19-1.mga7
+ Revision: 1151919
- version 1.3.5.19 fixes CVE-2017-7551 mga#21671

* Mon Apr 24 2017 neoclust <neoclust> 1.3.5.17-1.mga6
+ Revision: 1097227
- New version 1.3.5.17 - Fixes CVE-2017-2668 (mga#20659)

* Wed Mar 15 2017 mrambo3501 <mrambo3501> 1.3.5.15-5.mga6
+ Revision: 1092672
- Rebuild for icu-58.2

* Thu Feb 16 2017 mrambo3501 <mrambo3501> 1.3.5.15-4.mga6
+ Revision: 1086490
- rebuild for libevent 2.1.8

* Mon Jan 30 2017 mrambo3501 <mrambo3501> 1.3.5.15-3.mga6
+ Revision: 1084237
- add upstream patch to fix CVE-2017-2591

* Sat Jan 28 2017 akien <akien> 1.3.5.15-2.mga6
+ Revision: 1083792
- Rebuild for buildsystem issue

* Tue Nov 22 2016 mrambo3501 <mrambo3501> 1.3.5.15-1.mga6
+ Revision: 1068727
- update to version 1.3.5.15
- fixes CVE-2016-4992, CVE-2016-5405, CVE-2016-5416

* Thu Sep 29 2016 luigiwalser <luigiwalser> 1.3.5.13-2.mga6
+ Revision: 1057538
- 1.3.5.13 (fixes CVE-2016-4992)
- cosmetic spec cleanups (some synced from fedora)
- remove a bunch of stuff from the spec only needed in fedora
- remove patch0 (fixed upstream)
- remove no longer needed obsoletes
- add snmp subpackage (from fedora)

* Thu Jun 16 2016 daviddavid <daviddavid> 1.3.5.4-3.mga6
+ Revision: 1021701
- add a patch to fix build with new systemd

* Mon May 30 2016 spuhler <spuhler> 1.3.5.4-2.mga6
+ Revision: 1019467
- needs svrcore-devel >= 4.1.2
- removed build patch

* Sun May 29 2016 spuhler <spuhler> 1.3.5.4-1.mga6
+ Revision: 1019345
- added build patch provided by David Geiger
- upgrade to vesr. 1.3.5.4

* Sat May 14 2016 shlomif <shlomif> 1.3.5.1-4.mga6
+ Revision: 1015299
- Rebuild for the new UCI (new major)

* Sun Apr 17 2016 spuhler <spuhler> 1.3.5.1-3.mga6
+ Revision: 1003124
- fixed missing requires

* Sat Apr 16 2016 spuhler <spuhler> 1.3.5.1-2.mga6
+ Revision: 1003043
- removed non exixting file in files section
- need to bup rel because of failed upload
- removed "mkdir -p  %%{buildroot}%%{_sysconfdir}/systemd/system/%%{groupname}.wants"
  * mageia doesn't accept this
- removed obsolete patches
- removed obsolete patches
- update to vers. 1.3.5.1
  * changed user and group to dirsrv
- upgrade to vers. 1.3.5.1

* Tue Feb 16 2016 spuhler <spuhler> 1.3.4.8-1.mga6
+ Revision: 962476
- update to vers 1.3.4.8

* Wed Jan 27 2016 spuhler <spuhler> 1.3.4.7-1.mga6
+ Revision: 928283
- upgrade to ver. 1.3.4.7

* Wed Jan 20 2016 spuhler <spuhler> 1.3.4.6-3.mga6
+ Revision: 926131
- update to vers. 1.3.4.6

* Thu Jan 07 2016 spuhler <spuhler> 1.3.4.5-3.mga6
+ Revision: 920238
- rebuiuld for libicu
+ cjw <cjw>
- make the source rpm (build deps, sources) not depend on the build arch
- build nunc-stans in (a subdirectory of) the build dir
- run autoreconf for nunc-stans and use configure2_5x instead of configure to fix build
+ luigiwalser <luigiwalser>
- rebuild for icu

* Fri Nov 20 2015 spuhler <spuhler> 1.3.4.5-1.mga6
+ Revision: 904544
- update to vers.  1.3.4.5

* Tue Sep 08 2015 spuhler <spuhler> 1.3.4.4-1.mga6
+ Revision: 873992
- upgrade to vers. 1.3.4.4

* Tue Aug 04 2015 spuhler <spuhler> 1.3.4.3-2.mga6
+ Revision: 861116
-upgrade to 1.3.4.3

* Sun Jul 26 2015 cjw <cjw> 1.3.4.1-2.mga6
+ Revision: 857730
- rebuild for icu 55

* Thu Jun 25 2015 spuhler <spuhler> 1.3.4.1-1.mga6
+ Revision: 843166
- update to vers. 1.3.4.1

* Tue Jun 23 2015 spuhler <spuhler> 1.3.4.0-3.mga6
+ Revision: 841079
- incresed Rel.
- removed nunc_stans" build on 32 bit systems
  * doesn't build on 32 bit systems (confirmed by upstream)
- Removed "Requires: libtalloc libevent libtevent
  * system should take care of these
- reversed last commit
- changed the build of nunc-stans to Make (from %%make)
  * it may build this way
- corrected the BuildReqires (libs)
- build of "nunc_stans" enabled

* Mon Jun 22 2015 spuhler <spuhler> 1.3.4.0-1.mga6
+ Revision: 839556
- update to vers. 1.3.4.0
- added "nunc_stans_ver 0.1.4"
  * disabled the build (doesn't build)
- removed comment to tempfiles
- added additional buildrequires

* Thu Apr 30 2015 spuhler <spuhler> 1.3.3.10-1.mga5
+ Revision: 820863
- upgrade to version 1.3.3.10
- fixes security issue, bug #15796, CVE-2015-1854

* Sat Mar 07 2015 spuhler <spuhler> 1.3.3.9-1.mga5
+ Revision: 818071
- upgrade to vers. 1.3.3.9
  * fixes security issue CVE-2014-8105 and CVE-2014-8112 Bug # 15440
- removed 389-ds-base-1.3.2.0-build-module.patch
- changed %%post section to fix upgrade (bugfix by upstream)
- removed %%ifarch x86_64 as told by upstream (not needed anymore)
- upgrade fixes lots of bugs (details see logs in upstream)

* Fri Mar 06 2015 spuhler <spuhler> 1.3.3.6-2.mga5
+ Revision: 817911
- removed "--with-selinux" in the configure section
  * we don't provide selinux and it didn' work (setup-ds.pl) anymore with this option

* Sat Dec 06 2014 spuhler <spuhler> 1.3.3.6-1.mga5
+ Revision: 801732
- upgrade to ver. 1.3.3.6
 * lots of bug fixes

* Thu Nov 06 2014 spuhler <spuhler> 1.3.3.5-1.mga5
+ Revision: 795992
- upgrade to vers. 1.3.3.5
 * bug fixes from upstream

* Wed Oct 15 2014 umeabot <umeabot> 1.3.3.3-2.mga5
+ Revision: 741488
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 spuhler <spuhler> 1.3.3.3-1.mga5
+ Revision: 679287
- changed lib and devel names to comply with Mageia Policies
- changed /bin/ to %%{_bindir}
- corrected wrong %%systemd macro
- upgrade to vers. 1.3.3.3
  * fixed lots of bugs by upstream
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Sat Sep 06 2014 spuhler <spuhler> 1.3.3.0-1.mga5
+ Revision: 672823
- upgrade to version 1.3.3.0
 * lots of bugfixes by upstream, incl. memory leak

* Sat Aug 30 2014 spuhler <spuhler> 1.3.2.23-1.mga5
+ Revision: 669591
- upgrade to version 1.3.2.23

* Thu Aug 14 2014 spuhler <spuhler> 1.3.2.22-1.mga5
+ Revision: 662406
- upgrade to version 1.3.2.22

* Thu Aug 07 2014 spuhler <spuhler> 1.3.2.21-1.mga5
+ Revision: 660910
- upgrade to version 1.3.2.21
 * solves Bug 13878 - 389-ds-base new security issue CVE-2014-3562

* Wed Aug 06 2014 spuhler <spuhler> 1.3.2.20-1.mga5
+ Revision: 660088
- upgrade to ver.  1.3.2.20

* Wed Jul 09 2014 spuhler <spuhler> 1.3.2.19-1.mga5
+ Revision: 650989
- replaced %%global _hardened_build 1 with serverbuild
- moved libns-dshttpd.so* to the libs
- reversed most of last commit
- changed lib and devel names according to mga policy
- some spec cleaning

* Sun Jul 06 2014 spuhler <spuhler> 1.3.2.18-1.mga5
+ Revision: 644099
- upgrade to ver. 1.3.2.18

* Tue Jun 10 2014 spuhler <spuhler> 1.3.2.17-1.mga5
+ Revision: 635293
- upgrade to 1.3.2.17

* Sun Apr 06 2014 wally <wally> 1.3.2.16-2.mga5
+ Revision: 612235
- rebuild for new icu

* Fri Mar 14 2014 spuhler <spuhler> 1.3.2.16-1.mga5
+ Revision: 603924
- upgrade to ver. 1.3.2.16

* Fri Mar 14 2014 spuhler <spuhler> 1.3.2.15-1.mga5
+ Revision: 603919
- upgrade to ver. 1.3.2.15
- removed obsolete ereport patch
- upgrade to ver. 1.3.2.14

* Fri Feb 07 2014 spuhler <spuhler> 1.3.2.11-1.mga5
+ Revision: 584894
- upgrade to ver 1.3.2.11

* Wed Feb 05 2014 spuhler <spuhler> 1.3.2.10-1.mga5
+ Revision: 582771
- upgrade to ver. 1.3.2.10

* Mon Nov 25 2013 spuhler <spuhler> 1.3.2.7-1.mga4
+ Revision: 553513
- upgrade to version 1.3.2.7
 * upgrade to vers. 1.3.2.6 solves a ton of bugs, incl the ldif upgrade
 * to version 1.3.2.7 resolves the library problem that prevented it from starting

* Fri Nov 22 2013 spuhler <spuhler> 1.3.2.5-1.mga4
+ Revision: 552369
- upgrade to version 1.3.2.5
- resolves Security issue CVE-2013-4485, bug #11720
- bug fixes by upstream

* Tue Oct 22 2013 umeabot <umeabot> 1.3.2.2-2.mga4
+ Revision: 541510
- Mageia 4 Mass Rebuild

* Sat Oct 12 2013 spuhler <spuhler> 1.3.2.2-1.mga4
+ Revision: 496049
- upgrade to version 1.3.2.2

* Fri Oct 11 2013 spuhler <spuhler> 1.3.2.1-1.mga4
+ Revision: 495330
- upgrade to version 1.3.2.1
- rediffed build-module patch

* Mon Oct 07 2013 spuhler <spuhler> 1.3.2.0-1.mga4
+ Revision: 492794
-upgrade to version 1.3.2.0
 * Lot's of bug fixes from upstream
- removed 1.3.1.7 build-module.patch

* Wed Oct 02 2013 spuhler <spuhler> 1.3.1.11-1.mga4
+ Revision: 490172
- upgrade to vers. 1.3.1.1
- some cleanup of spec
- bug fixes by upstream
  * Set localrundir outside of the "with-fhs" block
  * Refine the check for @localrundir@
  * remove unnecessary typedef
  * Repl Sync does not compile against MozLDAP libraries

* Sat Sep 28 2013 spuhler <spuhler> 1.3.1.10-1.mga4
+ Revision: 488515
- upgrade to vers. 1.3.1.10
- bugfixes from upstream
 * RUV tombstone search with scope "one" doesn`t work
 * 389-ds-base does not compile against MozLDAP libraries
 * Set up replication/agreement before initializing the sub suffix, the sub suffix is not found by ldapsearch
 * 389-ds-base built with mozldap can crash from invalid free
 * idlistscanlimit per index/type/value
 * tmpfiles.d references /var/lock when they should reference /run/lock
 * PassSync removes User must change password flag on the Windows side
 * CLEANALLRUV doesnt run across all replicas
 * replication stops with excessive clock skew
 * Coverity fix - 11952 - for Ticket 47512
 * backend txn plugin fixup tasks should be done in a txn
 * Allow macro aci keywords to be case-insensitive
 * Under specific values of nsDS5ReplicaName, replication may get broken or updates missing
 * automember rebuild task not working as expected
 * valgrind - value mem leaks, uninit mem usage
 * fix breakage in slapi-nis introduced with the previous fix
 * start-dirsrv/restart-dirsrv/stop-disrv do not register with systemd correctly

* Fri Sep 27 2013 fwang <fwang> 1.3.1.7-2.mga4
+ Revision: 487459
- rebuild for icu 52

* Wed Sep 04 2013 fwang <fwang> 1.3.1.7-1.mga4
+ Revision: 475030
- more strict declares
- correctly build modules
+ spuhler <spuhler>
- added ereport.patch to make it build
- upgrade to version 1.3.1.7
- made the mkdir in the %%post section conditional
- upgrade to ver 1.3.1.6
- upgrade to ver. 1.3.1.5
- bug #10889 CVE-2013-2219 ACLs inoperative in some search scenarios
- bugfixes from upstream
  * delete present values should append values to deleted values
  * valgrind  - value mem leaks, uninit mem usage
  * Segfault in 389-ds-base-1.3.1.4-1.fc19 when setting up FreeIPA replication
  * Fix runtime errors caused by last patch.
  * Fix compilation warnings and header files
  * logconv.pl man page missing -m,-M,-B,-D
  * fix recent compiler warnings
  * Overflow in nsslapd-disk-monitoring-threshold
  * deadlock after adding and deleting entries
  * Disk Monitoring not checking filesystem with logs
+ luigiwalser <luigiwalser>
- rebuild for cyrus-sasl

* Wed Jul 31 2013 spuhler <spuhler> 1.3.1.4-1.mga4
+ Revision: 461328
- upgrade to 1.3.1.4
- bugfixes from upstream - Very large entryusn values after enabling the USN plugin and the lastusn value is negative.
 * Replication problem with add-delete requests on single-valued attributes
 * (phase 2) ldapdelete returns non-leaf entry error while trying to remove a leaf entry
 * (phase 1) ldapdelete returns non-leaf entry error while trying to remove a leaf entry
 * memory leaks in set_krb5_creds
 * version 4 Slow ldapmodify operation time for large quantities of multi-valued attribute values
 * provide default syntax plugin
 * Overflow in nsslapd-disk-monitoring-threshold
 * RHDS denies MODRDN access if ACI list contains any DENY rule
 * Memory leak in 389-ds-base 1.2.11.15
 * ldbm errors when adding/modifying/deleting entries
 * Disk Monitoring is not triggered as expected.
 * changelog db deadlocks with DNA and replication

* Wed Jul 17 2013 spuhler <spuhler> 1.3.1.3-1.mga4
+ Revision: 455121
- upgrade to ver 1.3.1.3
- added mkdir for systemd dir
-upgrade to version 1.3.1.0
- added Requires(post):   rpm-helper
- added Requires(preun):  rpm-helper
- added mageia nogroup patch to replace group nobody in the install script.
- added %%dir %%{_sysconfdir}/systemd/system/%%{groupname}.wants
  * needed to allow dirsrv@instance.service
+ fwang <fwang>
- rebuild for new icu

* Tue Apr 16 2013 spuhler <spuhler> 1.3.0.5-2.mga4
+ Revision: 410202
- replaced incorrect macro in post section  with Mageia macro
 - %%systemd_post with  %%_post_service

* Wed Apr 03 2013 spuhler <spuhler> 1.3.0.5-1.mga3
+ Revision: 407558
- upgrade to ver. 1.3.0.5
  Fixes to following issues from upstream
 - unintended information exposure when anonymous access is set to rootdse
 - crash in aci evaluation
 - ns-slapd crashes sporadically with segmentation fault in libslapd.so
 - Deadlock in DNA plug-in Ticket #576 - DNA: use event queue for config update only at the start up
 - 389-ds-base cannot handle Kerberos tickets with PAC
 - cleanAllRUV task fails to cleanup config upon completion

* Wed Mar 13 2013 spuhler <spuhler> 1.3.0.4-1.mga3
+ Revision: 402840
- upgrade to version 1.3.0.4 fixes
 * Bug 9349 - CVE-2013-0312 389-ds: unauthenticated denial of service vulnerability in handling of LDAPv3 control data
 * DS returns error 20 when replacing values of a multi-valued attribute (only when replication is enabled)
 * Slow role performance when using a lot of roles
 * Ticket 590 - ns-slapd segfaults while trying to delete a tombstone entry

* Mon Mar 04 2013 spuhler <spuhler> 1.3.0.3-1.mga3
+ Revision: 401340
- upgrade to 1.3.0.3
  Lots of bugfixes by upstream
 o Ticket #584 - Existence of an entry is not checked when its password is to be deleted
 o Ticket 562 - Crash when deleting suffix
 o Ticket #542 - Cannot dynamically set nsslapd-maxbersize
 o Ticket 556 - Don't overwrite certmap.conf during upgrade
 o Ticket 549 - DNA plugin no longer reports additional info when range is depleted
 o Ticket 541 - need to set plugin as off in ldif template
 o Ticket 541 - RootDN Access Control plugin is missing after upgrade
- cleaned up spec file
  aaded Requires: libselinux-utils

* Fri Jan 11 2013 umeabot <umeabot> 1.3.0-4.mga3
+ Revision: 345051
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Dec 18 2012 spuhler <spuhler> 1.3.0-3.mga3
+ Revision: 332415
- upgrade to rc2
  bumped rel

* Sun Dec 16 2012 spuhler <spuhler> 1.3.0-2.mga3
+ Revision: 331346
- upgrade to from a1 to rc1

* Sat Dec 01 2012 spuhler <spuhler> 1.3.0-1.mga3
+ Revision: 324211
- upgrade to 1.3.0

* Sat Dec 01 2012 fwang <fwang> 1.2.11.15-5.mga3
+ Revision: 323723
- rebuild for new pcre

* Sun Nov 25 2012 colin <colin> 1.2.11.15-4.mga3
+ Revision: 321807
- Do not ship the /var/lock folder
- Ensure tmpfiles.d is enabled in the DSCreate.pm script
- Add patch to create the .wants folder for systemd units.
- Do not ship any systemd folders in /etc

* Fri Nov 09 2012 fwang <fwang> 1.2.11.15-3.mga3
+ Revision: 316610
- rebuild for update icu

* Tue Nov 06 2012 fwang <fwang> 1.2.11.15-2.mga3
+ Revision: 314759
- rebuild for new icu

* Sun Oct 21 2012 spuhler <spuhler> 1.2.11.15-1.mga3
+ Revision: 308664
- upgrade to version 2.12.11.15

* Mon Oct 15 2012 spuhler <spuhler> 1.2.11.12-2.mga3
+ Revision: 305913
- changed the libname as done by upstream
  bumped rel

* Sat Oct 13 2012 spuhler <spuhler> 1.2.11.12-1.mga3
+ Revision: 305248
- added  LDFLAGS=-L%%{perl_archlib}/CORE
  commented out Requires: perl(:MODULE_COMPAT_%%(eval "`%%{__perl} -V:version`"; echo $version))
- added Buildrequires: krb5-devel
- fixed Requires naming
- mageified spec file and removed unneeded lines
- cleaned up spec file
- imported package 389-ds-base


* Wed Jul 18 2012 Rich Megginson <rmeggins@redhat.com> - 1.2.10.14-1
- Ticket #410 - Referential integrity plug-in does not work when update interval is not zero

* Mon Jul 16 2012 Rich Megginson <rmeggins@redhat.com> - 1.2.10.13-1
- Ticket #406 - Impossible to rename entry (modrdn) with Attribute Uniqueness plugin enabled
- Ticket #405 - referint modrdn not working if case is different

* Wed Jun 27 2012 Rich Megginson <rmeggins@redhat.com> - 1.2.10.12-1
- Ticket 378 - unhashed#user#password visible after changing password
-  fix typo in previous patch
- Trac Ticket 396 - Account Usability Control Not Working

* Tue Jun 26 2012 Rich Megginson <rmeggins@redhat.com> - 1.2.10.11-1
- rebase to 1.2.10.11 to pick up several crash + security fixes
- Ticket 365 - passwords in clear text in the audit log
- Ticket 378 - unhashed#user#password visible after changing password http
- Ticket 390 - [abrt] 389-ds-base-1.2.10.6-1.fc16: slapi_attr_value_cmp: Process /usr/sbin/ns-slapd was killed by signal 11 (SIGSEGV)
- Ticket #382 - DS Shuts down intermittently
- Trac Ticket #359 - Database RUV could mismatch the one in changelog under the stress
- Ticket #361: Bad DNs in ACIs can segfault ns-slapd
- Trac Ticket #338 - letters in object's cn get converted to lowercase when renaming object
- Ticket #347 - IPA dirsvr seg-fault during system longevity test

* Tue Apr 10 2012 Rich Megginson <rmeggins@redhat.com> - 1.2.10.4-5
- Bug 808770 - [abrt] 389-ds-base-1.2.10.4-2.fc16: index_range_read_ext: Process /usr/sbin/ns-slapd was killed by signal 11 (SIGSEGV)
- typo in previous patch

* Tue Apr 10 2012 Rich Megginson <rmeggins@redhat.com> - 1.2.10.4-4
- Bug 808770 - [abrt] 389-ds-base-1.2.10.4-2.fc16: index_range_read_ext: Process /usr/sbin/ns-slapd was killed by signal 11 (SIGSEGV)
- same as Ticket #336

* Wed Mar 28 2012 Rich Megginson <rmeggins@redhat.com> - 1.2.10.4-3
- Ticket #331 - transaction errors with db 4.3 and db 4.2

* Tue Mar 13 2012 Rich Megginson <rmeggins@redhat.com> - 1.2.10.4-2
- rebuild

* Tue Mar 13 2012 Rich Megginson <rmeggins@redhat.com> - 1.2.10.4-1
- Ticket #305 - Certain CMP operations hang or cause ns-slapd to crash

* Mon Mar  5 2012 Rich Megginson <rmeggins@redhat.com> - 1.2.10.3-1
- b05139b memleak in normalize_mods2bvals
- c0eea24 memleak in mep_parse_config_entry
- 90bc9eb handle null smods
- Ticket #305 - Certain CMP operations hang or cause ns-slapd to crash
- Ticket #306 - void function cannot return value
- ticket 304 - Fix kernel version checking in dsktune

* Thu Feb 23 2012 Rich Megginson <rmeggins@redhat.com> - 1.2.10.2-1
- Trac Ticket #298 - crash when replicating orphaned tombstone entry
- Ticket #281 - TLS not working with latest openldap
- Trac Ticket #290 - server hangs during shutdown if betxn pre/post op fails
- Trac Ticket #26 - Please support setting defaultNamingContext in the rootdse
- Ticket #124 - add Provides: ldif2ldbm to rpm

* Tue Feb 14 2012 Rich Megginson <rmeggins@redhat.com> - 1.2.10.1-1
- Ticket #294 - 389 DS Segfaults during replica install in FreeIPA

* Mon Feb 13 2012 Rich Megginson <rmeggins@redhat.com> - 1.2.10.0-1
- Ticket 284 - Remove unnecessary SNMP MIB files
- Ticket 51 - memory leaks in 389-ds-base-1.2.8.2-1.el5?
- Ticket 175 - logconv.pl improvements

* Thu Feb  2 2012 Rich Megginson <rmeggins@redhat.com> - 1.2.10-0.10.rc1
- ad9dd30 coverity 12488 Resource leak In attr_index_config(): Leak of memory or pointers to system resources
- Ticket #281 - TLS not working with latest openldap
- Ticket #280 - extensible binary filters do not work
- Ticket #279 - filter normalization does not use matching rules
- Trac Ticket #275 - Invalid read reported by valgrind
- Ticket #277 - cannot set repl referrals or state
- Ticket #278 - Schema replication update failed: Invalid syntax
- Ticket #39 - Account Policy Plugin does not work for simple binds when PAM Pass Through Auth plugin is enabled
- Ticket #13 - slapd process exits when put the database on read only mode while updates are coming to the server
- Ticket #87 - Manpages fixes
- c493fb4 fix a couple of minor coverity issues
- Ticket #55 - Limit of 1024 characters for nsMatchingRule
- Trac Ticket #274 - Reindexing entryrdn fails if ancestors are also tombstoned
- Ticket #6 - protocol error from proxied auth operation
- Ticket #38 - nisDomain schema is incorrect
- Ticket #273 - ruv tombstone searches don't work after reindex entryrdn
- Ticket #29 - Samba3-schema is missing sambaTrustedDomainPassword
- Ticket #22 - RFE: Support sendmail LDAP routing schema
- Ticket #161 - Review and address latest Coverity issues
- Ticket #140 - incorrect memset parameters
- Trac Ticket 35 - Log not clear enough on schema errors
- Trac Ticket 139 - eliminate the use of char *dn in favor of Slapi_DN *dn
- Trac Ticket #52 - FQDN set to nsslapd-listenhost makes the server start fail if IPv4-mapped-IPv6 address is given

* Tue Jan 24 2012 Rich Megginson <rmeggins@redhat.com> - 1.2.10-0.9.a8
- Ticket #272 - add tombstonenumsubordinates to schema

* Mon Jan 23 2012 Rich Megginson <rmeggins@redhat.com> - 1.2.10-0.8.a7
- fixes for systemd - remove .pid files after shutting down servers
- Ticket #263 - add systemd include directive
- Ticket #264 - upgrade needs better check for "server is running"

* Fri Jan 20 2012 Rich Megginson <rmeggins@redhat.com> - 1.2.10-0.7.a7
- Ticket #262 - pid file not removed with systemd
- Ticket #50 - server should not call a plugin after the plugin close function is called
- Ticket #18 - Data inconsitency during replication
- Ticket #49 - better handling for server shutdown while long running tasks are active
- Ticket #15 - Get rid of rwlock.h/rwlock.c and just use slapi_rwlock instead
- Ticket #257 - repl-monitor doesn't work if leftmost hostnames are the same
- Ticket #12 - 389 DS DNA Plugin / Replication failing on GSSAPI
- 6aaeb77 add a hack to disable sasl hostname canonicalization
- Ticket 168 - minssf should not apply to rootdse
- Ticket #177 - logconv.pl doesn't detect restarts
- Ticket #159 - Managed Entry Plugin runs against managed entries upon any update without validating
- Ticket 75 - Unconfigure plugin opperations are being called.
- Ticket 26 - Please support setting defaultNamingContext in the rootdse.
- Ticket #71 - unable to delete managed entry config
- Ticket #167 - Mixing transaction and non-transaction plugins can cause deadlock
- Ticket #256 - debug build assertion in ACL_EvalDestroy()
- Ticket #4 - bak2db gets stuck in infinite loop
- Ticket #162 - Infinite loop / spin inside strcmpi_fast, acl_read_access_allowed_on_attr, server DoS
- Ticket #3: acl cache overflown problem
- Ticket 1 - pre-normalize filter and pre-compile substring regex - and other optimizations
- Ticket 2 - If node entries are tombstone'd, subordinate entries fail to get the full DN.

* Thu Dec 15 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.10-0.6.a6
- Bug 755725 - 389 programs linked against openldap crash during shutdown
- Bug 755754 - Unable to start dirsrv service using systemd
- Bug 745259 - Incorrect entryUSN index under high load in replicated environment
- d439e3a use slapi_hexchar2int and slapi_str_to_u8 everywhere
- 5910551 csn_init_as_string should not use sscanf
- b53ba00 reduce calls to csn_as_string and slapi_log_error
- c897267 fix member variable name error in slapi_uniqueIDFormat
- 66808e5 uniqueid formatting - use slapi_u8_to_hex instead of sprintf
- 580a875 csn_as_string - use slapi_uN_to_hex instead of sprintf
- Bug 751645 - crash when simple paged fails to send entry to client
- Bug 752155 - Use restorecon after creating init script lock file

* Fri Nov  4 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.10-0.5.a5
- Bug 751495 - 'setup-ds.pl -u' fails with undefined routine 'updateSystemD'
- Bug 750625 750624 750622 744946 Coverity issues
- Bug 748575 - part 2 - rhds81 modrdn operation and 100%% cpu use in replication
- Bug 748575 - rhds81 modrn operation and 100%% cpu use in replication
- Bug 745259 - Incorrect entryUSN index under high load in replicated environment
- f639711 Reduce the number of DN normalization
- c06a8fa Keep unhashed password psuedo-attribute in the adding entry
- Bug 744945 - nsslapd-counters attribute value cannot be set to "off"
- 8d3b921 Use new PLUGIN_CONFIG_ENTRY feature to allow switching between txn and regular
- d316a67 Change referential integrity to be a betxnpostoperation plugin

* Fri Oct  7 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.10-0.4.a4
- Bug 741744 - part3 - MOD operations with chained delete/add get back error 53
- 1d2f5a0 make memberof transaction aware and able to be a betxnpostoperation plug in
- b6d3ba7 pass the plugin config entry to the plugin init function
- 28f7bfb set the ENTRY_POST_OP for modrdn betxnpostoperation plugins
- Bug 743966 - Compiler warnings in account usability plugin

* Wed Oct  5 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.10.a3-0.3
- 498c42b fix transaction support in ldbm_delete

* Wed Oct  5 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.10.a2-0.2
- Bug 740942 - allow resource limits to be set for paged searches independently of limits for other searches/operations
- Bug 741744 - MOD operations with chained delete/add get back error 53 on backend config
- Bug 742324 - allow nsslapd-idlistscanlimit to be set dynamically and per-user

* Tue Sep 27 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.10.a1-0.1
- Bug 739172 - Allow separate fractional attrs for incremental and total protocols
- 6120b3d Make all backend operations transaction aware
- 056cc35 Add support for pre/post db transaction plugins
- Bug 736712 - Modifying ruv entry deadlocks server
- Bug 590826 - Reloading database from ldif causes changelog to emit "data no longer matches" errors
- Bug 730387 - Add slapi_rwlock API and use POSIX rwlocks
- Bug 611438 - Add Account Usability Control support

* Tue Sep 13 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.9.10-3
- added back fedora-ds-base stuff so as not to break dependencies

* Wed Sep  7 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.9.10-2
- corrected source

* Wed Sep  7 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.9.10-1
- Bug 735114 - renaming a managed entry does not update mepmanagedby

* Thu Sep  1 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.9.9-1
- Bug 735121 - simple paged search + ip/dns based ACI hangs server
- Bug 722292 - (cov#11030) Leak of mapped_sdn in winsync rename code
- Bug 703990 - cross-platform - Support upgrade from Red Hat Directory Server
- Introducing an environment variable USE_VALGRIND to clean up the entry cache and dn cache on exit.

* Wed Aug 31 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.9.8-1
- Bug 732153 - subtree and user account lockout policies implemented?
- Bug 722292 - Entries in DS are not updated properly when using WinSync API

* Wed Aug 24 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.9.7-1
- Bug 733103 - large targetattr list with syntax errors cause server to crash or hang
- Bug 633803 - passwordisglobalpolicy attribute brakes TLS chaining
- Bug 732541 - Ignore error 32 when adding automember config
- Bug 728592 - Allow ns-slapd to start with an invalid server cert

* Wed Aug 10 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.9.6-1
- Bug 728510 - Run dirsync after sending updates to AD
- Bug 729717 - Fatal error messages when syncing deletes from AD
- Bug 729369 - upgrade DB to upgrade from entrydn to entryrdn format is not working.
- Bug 729378 - delete user subtree container in AD + modify password in DS == DS crash
- Bug 723937 - Slapi_Counter API broken on  32-bit F15
-   fixed again - separate tests for atomic ops and atomic bool cas

* Mon Aug  8 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.9.5-1
- Bug 727511 - ldclt SSL search requests are failing with "illegal error number -1" error
-  Fix another coverity NULL deref in previous patch

* Thu Aug  4 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.9.4-1
- Bug 727511 - ldclt SSL search requests are failing with "illegal error number -1" error
-  Fix coverity NULL deref in previous patch

* Wed Aug  3 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.9.3-1
- Bug 727511 - ldclt SSL search requests are failing with "illegal error number -1" error
-  previous patch broke build on el5

* Wed Aug  3 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.9.2-1
- Bug 727511 - ldclt SSL search requests are failing with "illegal error number -1" error

* Tue Aug  2 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.9.1-2
- Bug 723937 - Slapi_Counter API broken on  32-bit F15
-   fixed to use configure test for GCC provided 64-bit atomic functions

* Wed Jul 27 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.9.1-1
- Bug 663752 - Cert renewal for attrcrypt and encchangelog
-   this was "re-fixed" due to a deadlock condition with cl2ldif task cancel
- Bug 725953 - Winsync: DS entries fail to sync to AD, if the User's CN entry contains a comma
- Bug 725743 - Make memberOf use PRMonitor for it's operation lock
- Bug 725542 - Instance upgrade fails when upgrading 389-ds-base package
- Bug 723937 - Slapi_Counter API broken on  32-bit F15

* Fri Jul 15 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.9.0-1
- Bug 720059 - RDN with %% can cause crashes or missing entries
- Bug 709468 - RSA Authentication Server timeouts when using simple paged results on RHDS 8.2.
- Bug 691313 - Need TLS/SSL error messages in repl status and errors log
- Bug 712855 - Directory Server 8.2 logs "Netscape Portable Runtime error -5961 (TCP connection reset by peer.)" to error log whereas Directory Server 8.1 did not
- Bug 713209 - Update sudo schema
- Bug 719069 - clean up compiler warnings in 389-ds-base 1.2.9
- Bug 718303 - Intensive updates on masters could break the consumer's cache
- Bug 711679 - unresponsive LDAP service when deleting vlv on replica

* Mon Jun 27 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.9-0.2.a2
- 389-ds-base-1.2.9.a2
- look for separate openldap ldif library
- Split automember regex rules into separate entries
- writing Inf file shows SchemaFile = ARRAY(0xhexnum)
- add support for ldif files with changetype: add
- Bug 716980 - winsync uses old AD entry if new one not found
- Bug 697694 - rhds82 - incr update state stop_fatal_error "requires administrator action", with extop_result: 9
- bump console version to 1.2.6
- Bug 711679 - unresponsive LDAP service when deleting vlv on replica
- Bug 703703 - setup-ds-admin.pl asks for legal agreement to a non-existant file
- Bug 706209 - LEGAL: RHEL6.1 License issue for 389-ds-base package
- Bug 663752 - Cert renewal for attrcrypt and encchangelog
- Bug 706179 - DS can not restart after create a new objectClass has entryusn attribute
- Bug 711906 - ns-slapd segfaults using suffix referrals
- Bug 707384 - only allow FIPS approved cipher suites in FIPS mode
- Bug 710377 - Import with chain-on-update crashes ns-slapd
- Bug 709826 - Memory leak: when extra referrals configured

* Thu May 26 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.9-0.1.a1
- 389-ds-base-1.2.9.a1
- Auto Membership
- More Coverity fixes

* Mon May  2 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.8.3-1
- 389-ds-base-1.2.8.3
- Bug 700145 - userpasswd not replicating
- Bug 700557 - Linked attrs callbacks access free'd pointers after close
- Bug 694336 - Group sync hangs Windows initial Sync
- Bug 700215 - ldclt core dumps
- Bug 695779 - windows sync can lose old values when a new value is added
- Bug 697027 - 12 - minor memory leaks found by Valgrind + TET

* Thu Apr 14 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.8.2-1
- 389-ds-base-1.2.8.2
- Bug 696407 - If an entry with a mixed case RDN is turned to be
-    a tombstone, it fails to assemble DN from entryrdn

* Fri Apr  8 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.8.1-1
- 389-ds-base-1.2.8.1
- Bug 693962 - Full replica push loses some entries with multi-valued RDNs

* Tue Apr  5 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.8.0-1
- 389-ds-base-1.2.8.0
- Bug 693473 - rhds82 rfe - windows_tot_run to log Sizelimit exceeded instead of LDAP error - -1
- Bug 692991 - rhds82 - windows_tot_run: failed to obtain data to send to the consumer; LDAP error - -1
- Bug 693466 - Unable to change schema online
- Bug 693503 - matching rules do not inherit from superior attribute type
- Bug 693455 - nsMatchingRule does not work with multiple values
- Bug 693451 - cannot use localized matching rules
- Bug 692331 - Segfault on index update during full replication push on 1.2.7.5

* Mon Apr  4 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.8-0.9.rc5
- 389-ds-base-1.2.8.rc5
- Bug 692469 - Replica install fails after step for "enable GSSAPI for replication"

* Tue Mar 29 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.8-0.8.rc4
- 389-ds-base-1.2.8.rc4
- Bug 668385 - DS pipe log script is executed as many times as the dirsrv serv
ice is restarted
- 389-ds-base-1.2.8.rc3
- Bug 690955 - Mrclone fails due to the replica generation id mismatch

* Tue Mar 22 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.8-0.7.rc2
- 389-ds-base-1.2.8 release candidate 2 - git tag 389-ds-base-1.2.8.rc2
- Bug 689537 - (cov#10610) Fix Coverity NULL pointer dereferences
- Bug 689866 - ns-newpwpolicy.pl needs to use the new DN format
- Bug 681015 - RFE: allow fine grained password policy duration attributes
-              in days, hours, minutes, as well
- Bug 684996 - Exported tombstone cannot be imported correctly
- Bug 683250 - slapd crashing when traffic replayed
- Bug 668909 - Can't modify replication agreement in some cases
- Bug 504803 - Allow maxlogsize to be set if logmaxdiskspace is -1
- Bug 644784 - Memory leak in "testbind.c" plugin
- Bug 680558 - Winsync plugin fails to restrain itself to the configured subtree

* Wed Mar  2 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.8-0.6.rc1
- 389-ds-base-1.2.8 release candidate 1 - git tag 389-ds-base-1.2.8.rc1
- Bug 518890 - setup-ds-admin.pl - improve hostname validation
- Bug 681015 - RFE: allow fine grained password policy duration attributes in 
-     days, hours, minutes, as well
- Bug 514190 - setup-ds-admin.pl --debug does not log to file
- Bug 680555 - ns-slapd segfaults if I have more than 100 DBs
- Bug 681345 - setup-ds.pl should set SuiteSpotGroup automatically
- Bug 674852 - crash in ldap-agent when using OpenLDAP
- Bug 679978 - modifying attr value crashes the server, which is supposed to
-     be indexed as substring type, but has octetstring syntax
- Bug 676655 - winsync stops working after server restart
- Bug 677705 - ds-logpipe.py script is failing to validate "-s" and
-     "--serverpid" options with "-t".
- Bug 625424 - repl-monitor.pl doesn't work in hub node

* Mon Feb 28 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.8-0.5.a3
- Bug 676598 - 389-ds-base multilib: file conflicts
- split off libs into a separate -libs package

* Thu Feb 24 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.8-0.4.a3
- do not create /var/run/dirsrv - setup will create it instead
- remove the fedora-ds initscript upgrade stuff - we do not support that anymore
- convert the remaining lua stuff to plain old shell script

* Wed Feb  9 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.8-0.3.a3
- 1.2.8.a3 release - git tag 389-ds-base-1.2.8.a3
- Bug 675320 - empty modify operation with repl on or lastmod off will crash server
- Bug 675265 - preventryusn gets added to entries on a failed delete
- Bug 677774 - added support for tmpfiles.d
- Bug 666076 - dirsrv crash (1.2.7.5) with multiple simple paged result search
es
- Bug 672468 - Don't use empty path elements in LD_LIBRARY_PATH
- Bug 671199 - Don't allow other to write to rundir
- Bug 678646 - Ignore tombstone operations in managed entry plug-in
- Bug 676053 - export task followed by import task causes cache assertion
- Bug 677440 - clean up compiler warnings in 389-ds-base 1.2.8
- Bug 675113 - ns-slapd core dump in windows_tot_run if oneway sync is used
- Bug 676689 - crash while adding a new user to be synced to windows
- Bug 604881 - admin server log files have incorrect permissions/ownerships
- Bug 668385 - DS pipe log script is executed as many times as the dirsrv serv
ice is restarted
- Bug 675853 - dirsrv crash segfault in need_new_pw()

* Thu Feb  3 2011 Rich Megginson <rmeggins@redhat.com> - 1.2.8-0.2.a2
- 1.2.8.a2 release - git tag 389-ds-base-1.2.8.a2
- Bug 674430 - Improve error messages for attribute uniqueness
- Bug 616213 - insufficient stack size for HP-UX on PA-RISC
- Bug 615052 - intrinsics and 64-bit atomics code fails to compile
-    on PA-RISC
- Bug 151705 - Need to update Console Cipher Preferences with new ciphers
- Bug 668862 - init scripts return wrong error code
- Bug 670616 - Allow SSF to be set for local (ldapi) connections
- Bug 667935 - DS pipe log script's logregex.py plugin is not redirecting the 
-    log output to the text file
- Bug 668619 - slapd stops responding
- Bug 624547 - attrcrypt should query the given slot/token for
-    supported ciphers
- Bug 646381 - Faulty password for nsmultiplexorcredentials does not give any 
-    error message in logs

* Fri Jan 21 2011 Nathan Kinder <nkinder@redhat.com> - 1.2.8-0.1.a1
- 1.2.8-0.1.a1 release - git tag 389-ds-base-1.2.8.a1
- many bug fixes

* Thu Dec 16 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.7.5-1
- 1.2.7.5 release - git tag 389-ds-base-1.2.7.5
- Bug 663597 - Memory leaks in normalization code

* Fri Dec 10 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.7.4-1
- 1.2.7.4 release - git tag 389-ds-base-1.2.7.4
- Bug 661792 - Valid managed entry config rejected

* Wed Dec  8 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.7.3-1
- 1.2.7.3 release - git tag 389-ds-base-1.2.7.3
- Bug 658312 - Invalid free in Managed Entry plug-in
- Bug 641944 - Don't normalize non-DN RDN values

* Fri Dec  3 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.7.2-1
- 1.2.7.2 release - git tag 389-ds-base-1.2.7.2
- Bug 659456 - Incorrect usage of ber_printf() in winsync code
- Bug 658309 - Process escaped characters in managed entry mappings
- Bug 197886 - Initialize return value for UUID generation code
- Bug 658312 - Allow mapped attribute types to be quoted
- Bug 197886 - Avoid overflow of UUID generator

* Tue Nov 23 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.7.1-1
- 1.2.7.1 release - git tag 389-ds-base-1.2.7.1
- Bug 656515 - Allow Name and Optional UID syntax for grouping attributes
- Bug 656392 - Remove calls to ber_err_print()
- Bug 625950 - hash nsslapd-rootpw changes in audit log

* Fri Nov 19 2010 Nathan Kinder <nkinder@redhat.com> - 1.2.7-1
- 1.2.7 release - git tag 389-ds-base-1.2.7
- Bug 648949 - Merge dirsrv and dirsrv-admin policy modules into base policy

* Tue Nov  9 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.7-0.6.a5
- 1.2.7.a5 release - git tag 389-ds-base-1.2.7.a5
- Bug 643979 - Strange byte sequence for attribute with no values (nsslapd-ref
erral)
- Bug 635009 - Add one-way AD sync capability
- Bug 572018 - Upgrading from 1.2.5 to 1.2.6.a2 deletes userRoot
- put replication config entries in separate file
- Bug 567282 - server can not abandon searchRequest of "simple paged results"
- Bug 329751 - "nested" filtered roles searches candidates more than needed
- Bug 521088 - DNA should check ACLs before getting a value from the range

* Mon Nov  1 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.7-0.5.a4
- 1.2.7.a4 release - git tag 389-ds-base-1.2.7.a4
- Bug 647932 - multiple memberOf configuration adding memberOf where there is no member
- Bug 491733 - dbtest crashes
- Bug 606545 - core schema should include numSubordinates
- Bug 638773 - permissions too loose on pid and lock files
- Bug 189985 - Improve attribute uniqueness error message
- Bug 619623 - attr-unique-plugin ignores requiredObjectClass on modrdn operations
- Bug 619633 - Make attribute uniqueness obey requiredObjectClass

* Wed Oct 27 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.7-0.4.a3
- 1.2.7.a3 release - a2 was never released - this is a rebuild to pick up
- Bug 644608 - RHDS 8.1->8.2 upgrade fails to properly migrate ACIs
- Adding the ancestorid fix code to ##upgradednformat.pl.

* Fri Oct 22 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.7-0.3.a3
- 1.2.7.a3 release - a2 was never released
- Bug 644608 - RHDS 8.1->8.2 upgrade fails to properly migrate ACIs
- Bug 629681 - Retro Changelog trimming does not behave as expected
- Bug 645061 - Upgrade: 06inetorgperson.ldif and 05rfc4524.ldif
-              are not upgraded in the server instance schema dir

* Tue Oct 19 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.7-0.2.a2
- 1.2.7.a2 release - a1 was the OpenLDAP testday release
- git tag 389-ds-base-1.2.7.a2
- added openldap support on platforms that use openldap with moznss
- for crypto (F-14 and later)
- many bug fixes
- Account Policy Plugin (keep track of last login, disable old accounts)

* Fri Oct  8 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.7-0.1.a1
- added openldap support

* Thu Sep 29 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.6.1-2
- bump rev to rebuild

* Thu Sep 23 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.6.1-1
- This is the 1.2.6.1 release - git tag 389-ds-base-1.2.6.1
- Bug 634561 - Server crushes when using Windows Sync Agreement
- Bug 635987 - Incorrect sub scope search result with ACL containing ldap:///self
- Bug 612264 - ACI issue with (targetattr='userPassword')
- Bug 606920 - anonymous resource limit- nstimelimit - also applied to "cn=directory manager"
- Bug 631862 - crash - delete entries not in cache + referint

* Thu Aug 26 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.6-1
- This is the final 1.2.6 release

* Tue Aug 10 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.6-0.11.rc7
- 1.2.6 release candidate 7
- git tag 389-ds-base-1.2.6.rc7
- Bug 621928 - Unable to enable replica (rdn problem?) on 1.2.6 rc6

* Mon Aug  2 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.6-0.10.rc6
- 1.2.6 release candidate 6
- git tag 389-ds-base-1.2.6.rc6
- Bug 617013 - repl-monitor.pl use cpu upto 90%%
- Bug 616618 - 389 v1.2.5 accepts 2 identical entries with different DN formats
- Bug 547503 - replication broken again, with 389 MMR replication and TCP errors
- Bug 613833 - Allow dirsrv_t to bind to rpc ports
- Bug 612242 - membership change on DS does not show on AD
- Bug 617629 - Missing aliases in new schema files
- Bug 619595 - Upgrading sub suffix under non-normalized suffix disappears
- Bug 616608 - SIGBUS in RDN index reads on platforms with strict alignments
- Bug 617862 - Replication: Unable to delete tombstone errors
- Bug 594745 - Get rid of dirsrv_lib_t label

* Wed Jul 14 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.6-0.9.rc3
- make selinux-devel explicit Require the base package in order
- to comply with Fedora Licensing Guidelines

* Thu Jul  1 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.6-0.8.rc3
- 1.2.6 release candidate 3
- git tag 389-ds-base-1.2.6.rc3
- Bug 603942 - null deref in _ger_parse_control() for subjectdn
- 609256  - Selinux: pwdhash fails if called via Admin Server CGI
- 578296  - Attribute type entrydn needs to be added when subtree rename switch is on
- 605827 - In-place upgrade: upgrade dn format should not run in setup-ds-admin.pl
- Bug 604453 - SASL Stress and Server crash: Program quits with the assertion failure in PR_Poll
- Bug 604453 - SASL Stress and Server crash: Program quits with the assertion failure in PR_Poll
- 606920 - anonymous resource limit - nstimelimit - also applied to "cn=directory manager"

* Wed Jun 16 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.6-0.7.rc2
- 1.2.6 release candidate 2

* Mon Jun 14 2010 Nathan Kinder <nkinder@redhat.com> - 1.2.6-0.6.rc1
- install replication session plugin header with devel package

* Wed Jun  9 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.6-0.5.rc1
- 1.2.6 release candidate 1

* Tue Jun 01 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.2.6-0.4.a4.1
- Mass rebuild with perl-5.12.0

* Wed May 26 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.6-0.4.a4
- 1.2.6.a4 release

* Tue Apr  7 2010 Nathan Kinder <nkinder@redhat.com> - 1.2.6-0.4.a3
- 1.2.6.a3 release
- add managed entries plug-in
- many bug fixes
- moved selinux subpackage into base package

* Fri Apr  2 2010 Caolán McNamara <caolanm@redhat.com> - 1.2.6-0.3.a2
- rebuild for icu 4.4

* Mon Mar  2 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.6-0.2.a2
- 1.2.6.a2 release
- add support for matching rules
- many bug fixes

* Fri Jan 15 2010 Nathan Kinder <nkinder@redhat.com> - 1.2.6-0.1.a1
- 1.2.6.a1 release
- Added SELinux policy and subpackages

* Tue Jan 12 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.5-1
- 1.2.5 final release

* Mon Jan  4 2010 Rich Megginson <rmeggins@redhat.com> - 1.2.5-0.5.rc4
- 1.2.5.rc4 release

* Mon Dec 17 2009 Rich Megginson <rmeggins@redhat.com> - 1.2.5-0.4.rc3
- 1.2.5.rc3 release

* Thu Oct 29 2009 Rich Megginson <rmeggins@redhat.com> - 1.2.4-1
- 1.2.4 release
- resolves bug 221905 - added support for Salted MD5 (SMD5) passwords - primarily for migration
- resolves bug 529258 - Make upgrade remove obsolete schema from 99user.ldif

* Mon Sep 14 2009 Rich Megginson <rmeggins@redhat.com> - 1.2.3-1
- 1.2.3 release
- added template-initconfig to %%files
- %%posttrans now runs update to update the server instances
- servers are shutdown, then restarted if running before install
- scriptlets mostly use lua now to pass data among scriptlet phases

* Tue Sep 01 2009 Caolán McNamara <caolanm@redhat.com> - 1.2.2-2
- rebuild with new openssl to fix dependencies

* Tue Aug 25 2009 Rich Megginson <rmeggins@redhat.com> - 1.2.2-1
- backed out - added template-initconfig to %%files - this change is for the next major release
- bump version to 1.2.2
- fix reopened 509472 db2index all does not reindex all the db backends correctly
- fix 518520 -  pre hashed salted passwords do not work
- see https://bugzilla.redhat.com/show_bug.cgi?id=518519 for the list of
- bugs fixed in 1.2.2

* Fri Aug 21 2009 Tomas Mraz <tmraz@redhat.com> - 1.2.1-5
- rebuilt with new openssl

* Wed Aug 19 2009 Noriko Hosoi <nhosoi@redhat.com> - 1.2.1-4
- added template-initconfig to %%files

* Wed Aug 12 2009 Rich Megginson <rmeggins@redhat.com> - 1.2.1-3
- added BuildRequires pcre

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon May 18 2009 Rich Megginson <rmeggins@redhat.com> - 1.2.1-1
- change name to 389
- change version to 1.2.1
- added initial support for numeric string syntax
- added initial support for syntax validation
- added initial support for paged results including sorting

* Tue Apr 28 2009 Rich Megginson <rmeggins@redhat.com> - 1.2.0-4
- final release 1.2.0
- Resolves: bug 475338 - LOG: the intenal type of maxlogsize, maxdiskspace and minfreespace should be 64-bit integer
- Resolves: bug 496836 - SNMP ldap-agent on Solaris: Unable to open semaphore for server: 389
- CVS tag: FedoraDirSvr_1_2_0 FedoraDirSvr_1_2_0_20090428

* Mon Apr  6 2009 Rich Megginson <rmeggins@redhat.com> - 1.2.0-3
- re-enable ppc builds

* Thu Apr  2 2009 Rich Megginson <rmeggins@redhat.com> - 1.2.0-2
- exclude ppc builds - needs extensive porting work

* Mon Mar 30 2009 Rich Megginson <rmeggins@redhat.com> - 1.2.0-1
- new release 1.2.0
- Made devel package depend on mozldap-devel
- only create run dir if it does not exist
- CVS tag: FedoraDirSvr_1_2_0_RC1 FedoraDirSvr_1_2_0_RC1_20090330

* Mon Oct 30 2008 Noriko Hosoi <nhosoi@redhat.com> - 1.1.3-7
- added db4-utils to Requires for verify-db.pl

* Mon Oct 13 2008 Noriko Hosoi <nhosoi@redhat.com> - 1.1.3-6
- Enabled LDAPI autobind

* Thu Oct  9 2008 Rich Megginson <rmeggins@redhat.com> - 1.1.3-5
- updated update to patch bug463991-bdb47.patch

* Thu Oct  9 2008 Rich Megginson <rmeggins@redhat.com> - 1.1.3-4
- updated patch bug463991-bdb47.patch

* Mon Sep 29 2008 Rich Megginson <rmeggins@redhat.com> - 1.1.3-3
- added patch bug463991-bdb47.patch
- make ds work with bdb 4.7

* Wed Sep 24 2008 Rich Megginson <rmeggins@redhat.com> - 1.1.3-2
- rolled back bogus winsync memory leak fix

* Tue Sep 23 2008 Rich Megginson <rmeggins@redhat.com> - 1.1.3-1
- winsync api improvements for modify operations

* Fri Jun 13 2008 Rich Megginson <rmeggins@redhat.com> - 1.1.2-1
- This is the 1.1.2 release.  The bugs fixed can be found here
- https://bugzilla.redhat.com/showdependencytree.cgi?id=452721
- Added winsync-plugin.h to the devel subpackage

* Fri Jun  6 2008 Rich Megginson <rmeggins@redhat.com> - 1.1.1-2
- bump rev to rebuild and pick up new version of ICU

* Fri May 23 2008 Rich Megginson <rmeggins@redhat.com> - 1.1.1-1
- 1.1.1 release candidate - several bug fixes

* Wed Apr 16 2008 Rich Megginson <rmeggins@redhat.com> - 1.1.0.1-4
- fix bugzilla 439829 - patch to allow working with NSS 3.11.99 and later

* Tue Mar 18 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.1.0.1-3
- add patch to allow server to work with NSS 3.11.99 and later
- do NSS_Init after fork but before detaching from console

* Tue Mar 18 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.1.0.1-3
- add Requires for versioned perl (libperl.so)

* Wed Feb 27 2008 Rich Megginson <rmeggins@redhat.com> - 1.1.0.1-2
- previous fix for 434403 used the wrong patch
- this is the right one

* Wed Feb 27 2008 Rich Megginson <rmeggins@redhat.com> - 1.1.0.1-1
- Resolves bug 434403 - GCC 4.3 build fails
- Rolled new source tarball which includes Nathan's fix for the struct ucred
- NOTE: Change version back to 1.1.1 for next release
- this release was pulled from CVS tag FedoraDirSvr110_gcc43

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.1.0-5
- Autorebuild for GCC 4.3

* Thu Dec 20 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-4
- This is the GA release of Fedora DS 1.1
- Removed version numbers for BuildRequires and Requires
- Added full URL to source tarball

* Fri Dec 07 2007 Release Engineering <rel-eng at fedoraproject dot org> - 1.1.0-3
- Rebuild for deps

* Wed Nov  7 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-2.0
- This is the beta2 release
- new file added to package - /etc/sysconfig/dirsrv - for setting
- daemon environment as is usual in other linux daemons

* Thu Aug 16 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-1.2
- fix build breakage due to open()
- mock could not find BuildRequires: db4-devel >= 4.2.52
- mock works if >= version is removed - it correctly finds db4.6

* Fri Aug 10 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-1.1
- Change pathnames to use the pkgname macro which is dirsrv
- get rid of cvsdate in source name

* Fri Jul 20 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-0.3.20070720
- Added Requires for perldap, cyrus sasl plugins
- Removed template-migrate* files
- Added perl module directory
- Removed install.inf - setup-ds.pl can now easily generate one

* Mon Jun 18 2007 Nathan Kinder <nkinder@redhat.com> - 1.1.0-0.2.20070320
- added requires for mozldap-tools

* Tue Mar 20 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-0.1.20070320
- update to latest sources
- added migrateTo11 to allow migrating instances from 1.0.x to 1.1
- ldapi support
- fixed pam passthru plugin ENTRY method

* Fri Feb 23 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-0.1.20070223
- Renamed package to fedora-ds-base, but keep names of paths/files/services the same
- use the shortname macro (fedora-ds) for names of paths, files, and services instead
- of name, so that way we can continue to use e.g. /etc/fedora-ds instead of /etc/fedora-ds-base
- updated to latest sources

* Tue Feb 13 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-0.1.20070213
- More cleanup suggested by Dennis Gilmore
- This is the fedora extras candidate based on cvs tag FedoraDirSvr110a1

* Fri Feb  9 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-1.el4.20070209
- latest sources
- added init scripts
- use /etc as instconfigdir

* Wed Feb  7 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-1.el4.20070207
- latest sources
- moved all executables to _bindir

* Mon Jan 29 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-1.el4.20070129
- latest sources
- added /var/tmp/fedora-ds to dirs

* Fri Jan 26 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-8.el4.20070125
- added logconv.pl
- added slapi-plugin.h to devel package
- added explicit dirs for /var/log/fedora-ds et. al.

* Thu Jan 25 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-7.el4.20070125
- just move all .so files into the base package from the devel package

* Thu Jan 25 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-6.el4.20070125
- Move the plugin *.so files into the main package instead of the devel
- package because they are loaded directly by name via dlopen

* Fri Jan 19 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-5.el4.20070125
- Move the script-templates directory to datadir/fedora-ds

* Fri Jan 19 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-4.el4.20070119
- change mozldap to mozldap6

* Fri Jan 19 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-3.el4.20070119
- remove . from cvsdate define

* Fri Jan 19 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-2.el4.20070119
- Having a problem building in Brew - may be Release format

* Fri Jan 19 2007 Rich Megginson <rmeggins@redhat.com> - 1.1.0-1.el4.cvs20070119
- Changed version to 1.1.0 and added Release 1.el4.cvs20070119
- merged in changes from Fedora Extras candidate spec file

* Mon Jan 15 2007 Rich Megginson <rmeggins@redhat.com> - 1.1-0.1.cvs20070115
- Bump component versions (nspr, nss, svrcore, mozldap) to their latest
- remove unneeded patches

* Tue Jan 09 2007 Dennis Gilmore <dennis@ausil.us> - 1.1-0.1.cvs20070108
- update to a cvs snapshot
- fedorafy the spec 
- create -devel subpackage
- apply a patch to use mozldap not mozldap6
- apply a patch to allow --prefix to work correctly

* Mon Dec 4 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-16
- Fixed the problem where the server would crash upon shutdown in dblayer
- due to a race condition among the database housekeeping threads
- Fix a problem with normalized absolute paths for db directories

* Tue Nov 28 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-15
- Touch all of the ldap/admin/src/scripts/*.in files so that they
- will be newer than their corresponding script template files, so
- that make will rebuild them.

* Mon Nov 27 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-14
- Chown new schema files when copying during instance creation

* Tue Nov 21 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-13
- Configure will get ldapsdk_bindir from pkg-config, or $libdir/mozldap6

* Tue Nov 21 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-12
- use eval to sed ./configure into ../configure

* Tue Nov 21 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-11
- jump through hoops to be able to run ../configure

* Tue Nov 21 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-10
- Need to make built dir in setup section

* Tue Nov 21 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-9
- The template scripts needed to use @libdir@ instead of hardcoding
- /usr/lib
- Use make DESTDIR=$RPM_BUILD_ROOT install instead of %% makeinstall
- do the actual build in a "built" subdirectory, until we remove
- the old script templates

* Thu Nov 16 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-8
- Make replication plugin link with libdb

* Wed Nov 15 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-7
- Have make define LIBDIR, BINDIR, etc. for C code to use
- especially for create_instance.h

* Tue Nov 14 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-6
- Forgot to checkin new config.h.in for AC_CONFIG_HEADERS

* Tue Nov 14 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-5
- Add perldap as a Requires; update sources

* Thu Nov 9 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-4
- Fix ds_newinst.pl
- Remove obsolete #defines

* Thu Nov 9 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-3
- Update sources; rebuild to populate brew yum repo with dirsec-nss

* Tue Nov 7 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-2
- Update sources

* Thu Nov 2 2006 Rich Megginson <rmeggins@redhat.com> - 1.0.99-1
- initial revision
